<?php

namespace App\Http\Controllers\Admin;

use App\Models\Category;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\Product;
use Artesaos\SEOTools\Facades\SEOMeta;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\URL;

class CategoryController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('permission:admin-category-list', ['only' => ['index']]);
        $this->middleware('permission:admin-category-create', ['only' => ['create', 'store']]);
        $this->middleware('permission:admin-category-edit', ['only' => ['edit', 'update']]);
        $this->middleware('permission:admin-category-delete', ['only' => ['destroy']]);
    }
    public function index()
    {
        $categoreis = Category::query();

        if ($keyword = request('search')) {
            $categoreis->where('name', 'LIKE', "%{$keyword}%");
        }

        if ($keyword = request('parent')) {
            $categoreis->where('category_id', $keyword);
        } else {
            $categoreis->where('category_id', 0);
        }

        $categoreis = $categoreis->latest()->paginate(25);
        return view('admin.category.index', compact('categoreis'));
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $category = new Category();
        $action = URL::route('admin.category.store');
        $title = 'افزودن دسته بندی';
        $categoreis = Category::get();
        $categoreis = $categoreis->groupBy('category_id');
        return view('admin.category.create', compact(['category', 'action', 'title', 'categoreis']));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $category = Category::create($request->all());
        alert()->success('اطلاعات با موفقیت ثبت شد', 'پیغام سیستم')->persistent("تایید");
        return back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Category  $category
     * @return \Illuminate\Http\Response
     */
    public function show(Category $category)
    {
        $categories = $category->descendants()->add($category)->pluck('id');
        $products = Product::whereIn('category_id', $categories)->where('status', 1);
        $title = 'کلیه محصولات دسته بندی' . ' ' . $category->name;
        SEOMeta::setTitle($title);
        if ($keyword = request('search')) {
            $products->where('name', 'LIKE', "%{$keyword}%")->orWhere('code', 'LIKE', "%{$keyword}%");
        }
        $products = $products->latest()->paginate(25);
        return view('admin.category.products', compact('products', 'title', 'category'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Category  $category
     * @return \Illuminate\Http\Response
     */
    public function edit(Category $category)
    {
        $action = URL::route('admin.category.update', ['category' => $category]);
        $title = 'ویرایش  دسته بندی';
        $categoreis = Category::get();
        $categoreis = $categoreis->groupBy('category_id');
        return view('admin.category.create', compact(['category', 'categoreis', 'action', 'title']));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Category  $category
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Category $category)
    {
        $category->update($request->all());
        alert()->success('ویرایش  با موفقیت انجام شد', 'پیغام سیستم')->persistent('تایید');
        return redirect(route('admin.category.index'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Category  $category
     * @return \Illuminate\Http\Response
     */
    public function destroy(Category $category)
    {
        $category->delete();
        alert()->success('حذف با موفقیت انجام شد', 'پیغام سیستم')->persistent('تایید');
        return back();
    }
    public function orders(Category $category)
    {
        // $title = 'کلیه محصولات دسته بندی' . ' ' . $category->name;
        // SEOMeta::setTitle($title);
        // $categories = $category->descendants()->add($category)->pluck('id');
        // $products = Product::whereIn('category_id', $categories)
        // ->join('subfactors', 'products.id', '=', 'subfactors.product_id')
        // ->join('factors', 'subfactors.factor_id', '=', 'factors.id')
        // ->whereBetween('factors.date_factor', [jalalitomiladi(request('start_at')), jalalitomiladi(request('end_at'))])
        // ->select('products.*','subfactors.count as tedad','factors.code as co')->paginate(25);
  
        $title = 'کلیه محصولات دسته بندی' . ' ' . $category->name;
        SEOMeta::setTitle($title);
        $categories = $category->descendants()->add($category)->pluck('id');
        $products = Product::whereIn('category_id', $categories)->where('status', 1);
        $products = $products->latest()->paginate(25);
 
        return view('admin.category.query', compact('products', 'title', 'category'));
    }
}
