<?php
namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Notifications\Sms\NewUser;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use URL;
use Illuminate\Support\Facades\Notification;
use Artesaos\SEOTools\Facades\SEOMeta;
use Maatwebsite\Excel\Facades\Excel;
use App\Exports\UsersExport;
use App\Models\Ostan;

class CustomerController extends Controller
{
    public function __construct()
    {
        $this->middleware('permission:admin-user-list', ['only' => ['index']]);
       $this->middleware('permission:admin-user-create', ['only' => ['create','store']]);
       $this->middleware('permission:admin-user-edit', ['only' => ['edit','update','export']]);
       $this->middleware('permission:admin-user-delete', ['only' => ['destroy']]);
       $this->middleware('permission:admin-user-factor', ['only' => ['factor']]);
       $this->middleware('permission:admin-user-payment', ['only' => ['transaction']]);
    }
    public function index()
    {
        SEOMeta::setTitle('لیست کاربران');
        $customers = User::query();
        $customers->where('customer','1');
        if ($keyword = request('search')) {
            $customers->where('name', 'LIKE', "%{$keyword}%")->orWhere('family', 'LIKE', "%{$keyword}%");
        }
        $customers = $customers->latest()->paginate(25);
       return view('admin.customer.index',compact('customers'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
       
        $customer = new User;
        $action = URL::route('admin.customer.store');
        $title='افزودن مشتری ';
        SEOMeta::setTitle($title);
        $ostans=Ostan::all();
        return view('admin.customer.create',compact(['customer','action','title','ostans']));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'family' => ['required', 'string', 'max:255'],
            'mobile' => ['required', 'string', 'max:255', 'unique:users'],
            'email'=>['nullable','string','unique:users'],
            'status'=>['nullable','boolean'],
        ]);
        $customer=User::create([
            'name' => $data['name'],
            'family' => $data['family'],
            'password' => Hash::make(faTOen($data['mobile'])),
            'mobile' => faTOen($data['mobile']),
            'status'=> $data['status'],
            'type'=> 'user',
            'customer'=>1,
            'codemeli'=>$request->codemeli,
            'address'=>$request->address,
        ]);
        if (option('sms_on_user_register', 'off') == 'on') {
            Notification::send($customer, new NewUser($customer));
        }
    alert()->success('ثبت  با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
     return back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\User  $customer
     * @return \Illuminate\Http\Response
     */
    public function show(User $customer)
    {
        //
    }
    public function edit(User $customer)
    {
        $action = URL::route('admin.customer.update', ['customer' => $customer->id]);
        $title='ویرایش   مشتری';
         SEOMeta::setTitle($title);
        return view('admin.customer.create',compact(['customer','action','title']));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\User  $customer
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, User $customer)
    {
        $data = $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'family' => ['required', 'string', 'max:255'],
            'mobile' => ['required', 'string', 'max:255'],
            'email'=>['nullable','string'],
            'status'=>['nullable','boolean'],
        ]);

        $customer->update([
            'name' => $data['name'],
            'family' => $data['family'],
            'mobile' => faTOen($data['mobile']),
            'email'=> $data['email'],
            'status'=> $data['status'],
            'codemeli'=>$request->codemeli,
            'address'=>$request->address,
        ]);
        alert()->success('ویرایش  با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return redirect(route('admin.customer.index'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\User  $customer
     * @return \Illuminate\Http\Response
     */
    public function destroy(User $customer)
    {
        $customer->delete();
        alert()->success('حذف با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return back();
    }
}
