<?php

namespace App\Http\Controllers\Admin;


use App\Models\Factor;
use App\Http\Controllers\Controller;
use App\Http\Requests\StoreFactorRequest;
use App\Http\Requests\UpdateFactorRequest;
use App\Models\Period;
use App\Models\User;
use App\Models\Product;
use App\Notifications\Sms\NewFactor;
use URL;
use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Artesaos\SEOTools\Facades\SEOMeta;
use Maatwebsite\Excel\Facades\Excel;
use App\Exports\FactorExport;
use App\Notifications\Sms\RememberFactor;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;

class FactorController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('permission:admin-factor-list', ['only' => ['index']]);
        $this->middleware('permission:admin-factor-create', ['only' => ['create', 'store']]);
        $this->middleware('permission:admin-factor-edit', ['only' => ['edit', 'update']]);
        $this->middleware('permission:admin-factor-delete', ['only' => ['destroy']]);
        $this->middleware('permission:admin-factor-payment', ['only' => ['show']]);
        $this->middleware('permission:admin-factor-sms', ['only' => ['sms']]);
        $this->middleware('permission:admin-factor-export', ['only' => ['export']]);
    }
    public function index()
    {
        SEOMeta::setTitle('لیست فاکتور ها');
        $factors = Factor::query();
        if ($keyword = request('search')) {
            $factors->where('name', 'LIKE', "%{$keyword}%")->orWhere('code', 'LIKE', "%{$keyword}%");
        }
        $users = User::where('type', 'user')->get();
        $factors = $factors->latest()->paginate(25);
        return view('admin.factor.index', compact('factors','users'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $factor = new Factor;
        $users = User::where('type', 'user')->get();
        $periods = Period::where('active', '1')->get();
        $products = Product::all();
        $action = URL::route('admin.factor.store');
        $title = 'افزودن فاکتور';
        SEOMeta::setTitle($title);
        return view('admin.factor.create', compact(['factor', 'action', 'title', 'users', 'products', 'periods']));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \App\Http\Requests\StoreFactorRequest  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreFactorRequest $request)
    {

        $factor = Factor::create([
            'name' => $request->name,
            'code' => $request->code,
            'date_factor' => $request->date_factor,
            'duedate_factor' => jalalitomiladi($request->date_factor)->addDays($request->period),
            'period' => $request->period,
            'expire_date' => $request->expire_date,
            'notifications' => $request->notifications,
            'pardakht' => $request->pardakht,
            'installment' => $request->installment,
            'themplate' => $request->themplate,
            'description' => $request->description,
            'user_id' => $request->user_id,
            'link' => Str::random(10),
        ]);

        foreach ($request->groupa as $key => $value) {

            if (isset($value['product_id'])) {
                $product_id = $value['product_id'];
                $name = Product::find($value['product_id'])->name;
            } else {
                $name = $value['name'];
                $product_id = Null;
            }
            $a = $factor->subfactors()->create([
                'name' => $name,
                'count' => $value['count'],
                'price' => $value['price'],
                'discount' => $value['discount'],
                'tax' => $value['tax'],
                'product_id' => $product_id,
                'type' => $value['type'],

            ]);

            if ($value['type'] == 'product')
                updateCountProduct($a);
        }
        if ($request->installment > 0) {
            for ($i = 1; $i <= $request->installment; $i++) {
                $factor->installments()->create([
                    'user_id' => $request->user_id,
                    'price' => ceil(total($factor) / $request->installment),
                    'part' => $i,
                    'name' => 'قسط شماره' . $i,
                    'due_date' => jalalitomiladi($request->date_factor)->addMonths($i - 1),
                    'status' => 0
                ]);
              
            }
            $pay=$factor->installments->sortByDesc('due_date')->first();
            $a=$pay->price* $request->installment;
            $b=$a-total($factor);
            $pay->price=$pay->price-$b;
            $pay->save();

        }
        if (option('sms_send_new_factor', 'off') == 'on' and $factor->notifications) {
            Notification::send($factor->user, new NewFactor($factor));
        }
        if($request->hasFile('file'))
        {
            $factor->file()->create([
                'file' =>storeFile($request->file,'factor',1)
            ]);
        }
        alert()->success('ثبت  اطلاعات با موفقیت انجام شد', 'پیغام سیستم')->persistent('تایید');
        return back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Factor  $factor
     * @return \Illuminate\Http\Response
     */
    public function show(Factor $factor)
    {
        SEOMeta::setTitle('لیست پرداختی فاکتور' . ' ' . $factor->code);
        $transactions = $factor->transactions->where('status', 1);
        return view('admin.factor.payment', compact('factor', 'transactions'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Factor  $factor
     * @return \Illuminate\Http\Response
     */
    public function edit(Factor $factor)
    {

        $users = User::where('type', 'user')->get();
        $periods = Period::where('active', '1')->get();
        $products = Product::all();
        $action = URL::route('admin.factor.update', ['factor' => $factor->id]);
        $subfactors = $factor->subfactors;
        $title = 'ویرایش فاکتور';
        SEOMeta::setTitle($title);
        return view('admin.factor.edit', compact(['factor', 'action', 'title', 'users', 'products', 'periods', 'subfactors']));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \App\Http\Requests\UpdateFactorRequest  $request
     * @param  \App\Models\Factor  $factor
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateFactorRequest $request, Factor $factor)
    {

        $factor->update([
            'name' => $request->name,
            'code' => $request->code,
            'date_factor' => $request->date_factor,
            'duedate_factor' => jalalitomiladi($request->date_factor)->addDays($request->period),
            'period' => $request->period,
            'expire_date' => $request->expire_date,
            'pardakht' => $request->pardakht,
            'notifications' => $request->notifications,
            'installment' => $request->installment,
            'themplate' => $request->themplate,
            'description' => $request->description,
            'user_id' => $request->user_id,
        ]);
        $factor->subfactors()->delete();
        foreach ($request->groupa as $key => $value) {

            if (isset($value['product_id'])) {
                $product_id = $value['product_id'];
                $name = Product::find($value['product_id'])->name;
            } else {
                $name = $value['name'];
                $product_id = Null;
            }
            $a = $factor->subfactors()->create([
                'name' => $name,
                'count' => $value['count'],
                'price' => $value['price'],
                'discount' => $value['discount'],
                'tax' => $value['tax'],
                'product_id' => $product_id,
                'type' => $value['type'],

            ]);
            if ($value['type'] == 'product')
                updateCountProduct($a, $value['old_count']);
        }

        if($request->hasFile('file'))
        {
            if(!empty($factor->file))
            {
                $factor->file()->update([
                    'file' =>storeFile($request->file,'factor',1)
                ]);
            }
            else
            {
                $factor->file()->create([
                    'file' =>storeFile($request->file,'factor',1)
                ]); 
            }
        }

        alert()->success('ویرایش  اطلاعات با موفقیت انجام شد', 'پیغام سیستم')->persistent('تایید');
        return redirect()->route('admin.factor.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Factor  $factor
     * @return \Illuminate\Http\Response
     */
    public function destroy(Factor $factor)
    {
        foreach ($factor->subfactors as $item) {
            if ($item->type == 'product')
                updateCountProduct($item,$item->count*2);
        }
        $factor->delete();
        alert()->success('حذف اطلاعات با موفقیت انجام شد', 'پیغام سیستم')->persistent('تایید');
        return back();
    }
    public function sms(Factor $factor)
    {
        if (option('sms_send_new_factor', 'off') == 'on') {
            Notification::send($factor->user, new RememberFactor($factor));
        }
        alert()->success('پیامک با موفقیت ارسال شد', 'پیغام سیستم')->persistent('تایید');
        return back();
    }
    public function export()
    {
        return Excel::download(new FactorExport, 'factor.xlsx');
    }
    public function download(Factor $factor)
    {
        $pathToFile = storage_path('app/' . $factor->file->file);
        return response()->download($pathToFile);
    }
}
