<?php

namespace App\Http\Controllers\Admin;
use App\Http\Controllers\Controller;

use App\Models\Installment;
use App\Http\Requests\StoreInstallmentRequest;
use App\Http\Requests\UpdateInstallmentRequest;
use App\Models\Factor;
use App\Notifications\Sms\OkFactorUser;
use Artesaos\SEOTools\Facades\SEOMeta;
use Illuminate\Support\Facades\Notification;
use Illuminate\Http\Request;
class InstallmentController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
          $this->middleware('permission:admin-factor-installments', ['only' => ['factor','store','update','destory']]);
          $this->middleware('permission:admin-installment-create', ['only' => ['installment','store']]);
          $this->middleware('permission:admin-installment-update', ['only' => ['update']]);
          $this->middleware('permission:admin-installment-delete', ['only' => ['destroy']]);

        
    }
    public function index()
    {
        //
    }
    public function factor(Factor $factor)
    {
        SEOMeta::setTitle('لیست اقساط فاکتور'.' '.$factor->code);
       $installments=$factor->installments;
       return view('admin.factor.installments',compact('factor','installments'));
    }

    public function installment(Request $request,Factor $factor)
    {
        $factor=Factor::find($factor->id);
        if ($request->installment > 0) {
            $factor->installments()->where('status',0)->delete();
            $j=$factor->installments()->count();
            for ($i =$j+1; $i <= $request->installment+ $j; $i++) {
                $factor->installments()->create([
                    'user_id' => $factor->user_id,
                    'price' => ceil(notpaymentfactor($factor) / $request->installment),
                    'part' => $i,
                    'name' => 'قسط شماره' . $i,
                    'due_date' => jalalitomiladi($request->start_at)->addMonths($i - $j+1),
                    'status' => 0
                ]);
              
            }
            $pay=$factor->installments->sortByDesc('due_date')->first();
            $a=$pay->price* $request->installment;
            $b=$a-notpaymentfactor($factor);
            $pay->price=$pay->price-$b;
            $pay->save();
           
            alert()->success('ثبت  اطلاعات با موفقیت انجام شد', 'پیغام سیستم')->persistent('تایید');
            return back();

        }
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \App\Http\Requests\StoreInstallmentRequest  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreInstallmentRequest $request)
    {
        $request->merge([
            'due_date' => jalalitomiladi($request->due_date),
        ]);
        $installment=Installment::create($request->all());
        return back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Installment  $installment
     * @return \Illuminate\Http\Response
     */
    public function show(Installment $installment)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Installment  $installment
     * @return \Illuminate\Http\Response
     */
    public function edit(Installment $installment)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \App\Http\Requests\UpdateInstallmentRequest  $request
     * @param  \App\Models\Installment  $installment
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateInstallmentRequest $request, Installment $installment)
    {
        $request->merge([
            'due_date' => jalalitomiladi($request->due_date),
        ]);
        $installment->update($request->all());

        if ($request->status == 1) {
            $factor = Factor::find($request->factor_id);
            if (str_replace(',', '', $request->price) > notpaymentfactor($factor)) {
                alert()->error('مبلغ پرداختی از مبلغ باقی مانده بیشتر می باشد', 'پیغام سیستم')->persistent('تایید');
                return back()->withInput(($request->all()));
            }
            $request->request->add(['user_id' => $factor->user_id]);
            $request->request->add(['transid' => rand(10000000, 99999999)]); //add request
            $request->request->add(['status' => '1']); //add request 
            $request->request->add(['description' => $installment->name]);
            $request->request->add(['installment' => 1]);
            $transaction = $factor->transactions()->create($request->all());
            $installment->transaction_id =  $transaction->id;
            $installment->save();
            if (option('sms_ok_factor_user', 'off') == 'on') {
                Notification::send($transaction->user, new OkFactorUser($transaction));
            }
        }
        return back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Installment  $installment
     * @return \Illuminate\Http\Response
     */
    public function destroy(Installment $installment)
    {
        $installment->delete();
        return back();
    }
}
