<?php

namespace App\Http\Controllers\Admin;

use App\Models\Period;
use App\Http\Controllers\Controller;
use App\Http\Requests\StorePeriodRequest;
use App\Http\Requests\UpdatePeriodRequest;
use URL;
use Artesaos\SEOTools\Facades\SEOMeta;

class PeriodController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
       $this->middleware('permission:admin-setting-period', ['only' => ['index','create','update','destroy','edit']]);

    }
    public function index()
    {
        SEOMeta::setTitle('مدیریت دوره های زمانی ');
        $periods = Period::query();
        if ($keyword = request('search')) {
            $periods->where('name', 'LIKE', "%{$keyword}%")->orWhere('day', 'LIKE', "%{$keyword}%");
        }
        $periods = $periods->latest()->paginate(25);
       return view('admin.period.index',compact('periods'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $period = new Period;
        $action = URL::route('admin.period.store');
        $title='افزودن دوره تکرار';
        SEOMeta::setTitle($title);
        return view('admin.period.create',compact(['period','action','title']));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \App\Http\Requests\StorePeriodRequest  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StorePeriodRequest $request)
    {
        $period=Period::create($request->all());
    alert()->success('ثبت  با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
     return back()->with('success', 'your message,here');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Period  $period
     * @return \Illuminate\Http\Response
     */
    public function show(Period $period)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Period  $period
     * @return \Illuminate\Http\Response
     */
    public function edit(Period $period)
    {
        $action = URL::route('admin.period.update', ['period' => $period->id]);
        $title='ویرایش دوره';
        SEOMeta::setTitle($title);
        return view('admin.period.create',compact(['period','action','title']));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \App\Http\Requests\UpdatePeriodRequest  $request
     * @param  \App\Models\Period  $period
     * @return \Illuminate\Http\Response
     */
    public function update(UpdatePeriodRequest $request, Period $period)
    {
      
        $period->update($request->all());
        alert()->success('ویرایش  با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return redirect(route('admin.period.index'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Period  $period
     * @return \Illuminate\Http\Response
     */
    public function destroy(Period $period)
    {
        $period->delete();
        alert()->success('حذف اطلاعات با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return back();
    }
}
