<?php

namespace App\Http\Controllers\Admin;
use App\Http\Controllers\Controller;
use App\Models\User;
use App\Notifications\Sms\NewUser;
use Spatie\Permission\Models\Role;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use URL;
use Illuminate\Support\Facades\Notification;
use Artesaos\SEOTools\Facades\SEOMeta;
use Maatwebsite\Excel\Facades\Excel;
use App\Exports\UsersExport;
use App\Repository\UserRepositoryInterface;

class PersenelController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */


    public function __construct()
    {
        $this->middleware('permission:admin-user-list', ['only' => ['index']]);
       $this->middleware('permission:admin-user-create', ['only' => ['create','store']]);
       $this->middleware('permission:admin-user-edit', ['only' => ['edit','update','export']]);
       $this->middleware('permission:admin-user-delete', ['only' => ['destroy']]);
       $this->middleware('permission:admin-user-factor', ['only' => ['factor']]);
       $this->middleware('permission:admin-user-payment', ['only' => ['transaction']]);
    }
    public function index()
    {
        SEOMeta::setTitle('لیست پرسنل');
        $persenels = User::query();
        $persenels->where('persenel','1');
        if ($keyword = request('search')) {
            $persenels->where('name', 'LIKE', "%{$keyword}%")->orWhere('family', 'LIKE', "%{$keyword}%");
        }
        $persenels = $persenels->latest()->paginate(25);
       return view('admin.persenel.index',compact('persenels'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
       
        $persenel = new User;
        $action = URL::route('admin.persenel.store');
        $title='افزودن پرسنل ';
        SEOMeta::setTitle($title);
        return view('admin.persenel.create',compact(['persenel','action','title']));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'family' => ['required', 'string', 'max:255'],
            'mobile' => ['required', 'string', 'max:255', 'unique:users'],
            'email'=>['nullable','string','unique:users'],
            'status'=>['nullable','boolean'],
        ]);
        $persenel=User::create([
            'name' => $data['name'],
            'family' => $data['family'],
            'password' => Hash::make(faTOen($data['mobile'])),
            'mobile' => faTOen($data['mobile']),
            'email'=> $data['email'],
            'status'=> $data['status'],
            'type'=> 'persenel',
            'persenel'=>1,
            'customer'=>1,
            'codemeli'=>$request->codemeli,
            'address'=>$request->address,
        ]);
        if (option('sms_on_user_register', 'off') == 'on') {
            Notification::send($persenel, new NewUser($persenel));
        }
    alert()->success('ثبت  با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
     return back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\User  $persenel
     * @return \Illuminate\Http\Response
     */
    public function show(User $persenel)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\User  $persenel
     * @return \Illuminate\Http\Response
     */
    public function edit(User $persenel)
    {
        $action = URL::route('admin.persenel.update', ['persenel' => $persenel->id]);
        $title='ویرایش کاربر / مشتری';
         SEOMeta::setTitle($title);
        return view('admin.persenel.create',compact(['persenel','action','title']));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\User  $persenel
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, User $persenel)
    {
        $data = $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'family' => ['required', 'string', 'max:255'],
            'mobile' => ['required', 'string', 'max:255'],
            'email'=>['nullable','string'],
            'status'=>['nullable','boolean'],
        ]);

        $persenel->update([
            'name' => $data['name'],
            'family' => $data['family'],
            'mobile' => faTOen($data['mobile']),
            'email'=> $data['email'],
            'status'=> $data['status'],
            'codemeli'=>$request->codemeli,
            'address'=>$request->address,
        ]);
        alert()->success('ویرایش  با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return redirect(route('admin.persenel.index'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\User  $persenel
     * @return \Illuminate\Http\Response
     */
    public function destroy(User $persenel)
    {
        $persenel->delete();
        alert()->success('حذف با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return back();
    }
}
