<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\Post;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\URL;

class PostController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
       $this->middleware('permission:admin-post-list', ['only' => ['index']]);
       $this->middleware('permission:admin-post-create', ['only' => ['create','store']]);
       $this->middleware('permission:admin-post-edit', ['only' => ['edit','update']]);
       $this->middleware('permission:admin-post-delete', ['only' => ['destroy']]);
    }
    public function index()
    {
        $posts = Post::query();

        if ($keyword = request('search')) {
            $posts->where('name', 'LIKE', "%{$keyword}%")->orWhere('content', 'LIKE', "%{$keyword}%")->orWhere('fullcontent', 'LIKE', "%{$keyword}%");
        }
        $posts = $posts->latest()->paginate(25);

        return view('admin.post.index', compact('posts'));
        $posts = post::whereDate('created_at', Carbon::today())->get();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $post = new Post();
        $action = URL::route('admin.post.store');
        $title = 'افزودن مطلب';
        $categoreis = Category::where('type', 'post')->get();
        $postcategory = array();
        $queiz = array();
        $images = array();
        return view('admin.post.create', compact(['post', 'action', 'title', 'images', 'queiz', 'categoreis', 'postcategory']));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // Storage::disk('s3')->putFileAs('test' , $request->file('file'), $request->file('file')->getClientOriginalName());
        $post = auth()->user()->posts()->create(
            [
                'name' => $request->name,
                'content' => $request->content,
                'fullcontent' => $request->fullcontent,
                'active' => $request->active,
                'comment' => $request->comment,
                'noti' => $request->noti,
                'pic' => $request->pic,
                'type' => $request->type,
                'description' => $request->description,
                'keyword' => $request->keyword,
                'picheader' => $request->picheader
            ]
        );

        if ($request->groupb) {
            foreach ($request->groupb as $key => $value) {
                if ($value['names'] != '') {
                    $post->questions()->create([
                        'name' => $value['names'],
                        'value' => $value['pasokh'],
                    ]);
                }
            }
        }
        if ($request->groupa) {
            foreach ($request->groupa as $key => $value) {
                if ($value['names'] != '') {
                    $post->images()->create([
                        'name' => $value['names'],
                        'pic' => $value['pic'],
                    ]);
                }
            }
        }
        $post->categories()->sync($request->category);
        alert()->success('اطلاعات با موفقیت ثبت شد', 'پیغام سیستم')->persistent("تایید");
        return back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\post  $post
     * @return \Illuminate\Http\Response
     */
    public function show(post $post)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\post  $post
     * @return \Illuminate\Http\Response
     */
    public function edit(post $post)
    {
        $action = URL::route('admin.post.update', ['post' => $post]);
        $title = 'ویرایش  مطلب';
        $categoreis = Category::where('type', 'post')->get();
        $postcategory = $post->categories->pluck('id')->toArray();
        $queiz = $post->questions()->get();
        $images = $post->images()->get();
        return view('admin.post.create', compact(['post', 'images', 'queiz', 'postcategory', 'categoreis', 'action', 'title']));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\post  $post
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, post $post)
    {
        $post->update(
            [
                'name' => $request->name,
                'slug' => $request->slug,
                'content' => $request->content,
                'fullcontent' => $request->fullcontent,
                'active' => $request->active,
                'comment' => $request->comment,
                'noti' => $request->noti,
                'pic' => $request->pic,
                'type' => $request->type,
                'description' => $request->description,
                'keyword' => $request->keyword,
                'picheader' => $request->picheader
            ]
        );

        $post->questions()->delete();
        if ($request->groupb) {
            foreach ($request->groupb as $key => $value) {
                if ($value['names'] != '') {
                $post->questions()->create([
                    'name' => $value['names'],
                    'value' => $value['pasokh'],
                ]);
            }
            }
        }
        $post->images()->delete();
        if ($request->groupa) {
            foreach ($request->groupa as $key => $value) {
                if ($value['names'] != '') {
                    $post->images()->create([
                        'name' => $value['names'],
                        'pic' => $value['pic'],
                    ]);
                }
            }
        }
        $post->categories()->sync($request->category);
        alert()->success('ویرایش  با موفقیت انجام شد', 'پیغام سیستم')->persistent('تایید');
        return redirect(route('admin.post.index'));
    }
    public function changeSardabir(Request $request)

    {

        $post = post::find($request->post_id);
        $post->sardabir = $request->status;
        $post->save();
        return response()->json(['success' => 'تغییرات با موفقیت ذخیره شد.']);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\post  $post
     * @return \Illuminate\Http\Response
     */
    public function destroy(post $post)
    {
        $post->delete();
        alert()->success('حذف با موفقیت انجام شد', 'پیغام سیستم')->persistent('تایید');
        return back();
    }
}
