<?php

namespace App\Http\Controllers\Admin;
use App\Models\Product;
use App\Http\Controllers\Controller;
use App\Http\Requests\StoreProductRequest;
use App\Http\Requests\UpdateProductRequest;
use URL;
use Artesaos\SEOTools\Facades\SEOMeta;
use Maatwebsite\Excel\Facades\Excel;
use App\Exports\ProductExport;
use Illuminate\Support\Str;

class ProductController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
       $this->middleware('permission:admin-product-list', ['only' => ['index']]);
       $this->middleware('permission:admin-product-create', ['only' => ['create','store']]);
       $this->middleware('permission:admin-product-edit', ['only' => ['edit','update']]);
       $this->middleware('permission:admin-product-delete', ['only' => ['destroy']]);
    }
    public function index()
    {
        SEOMeta::setTitle('لیست محصولات ');
        $products = Product::query();
        if ($keyword = request('search')) {
            $products->where('name', 'LIKE', "%{$keyword}%")->orWhere('code', 'LIKE', "%{$keyword}%");
        }
        $products = $products->latest()->paginate(25);
       return view('admin.product.index',compact('products'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
       
        $product = new Product;
        $action = URL::route('admin.product.store');
        $title='افزودن محصول';
        SEOMeta::setTitle( $title);
        return view('admin.product.create',compact(['product','action','title']));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \App\Http\Requests\StoreProductRequest  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreProductRequest $request)
    {
        $request->merge(['price' => remove(',',$request->price)]);
        $request->merge(['price_buy' => remove(',',$request->price_buy)]);
        if($request->hasFile('picture'))
        {
        $request->merge(['pic' => storeFile($request->picture,'uploads/product/')]);
        }
      
        $request->merge(['link' =>  Str::random(10)]);
        $product=Product::create($request->all());
        if($request->hasFile('file'))
        {
            $product->file()->create([
                'file' =>storeFile($request->file,'product/',1)
            ]);
        }
    alert()->success('ثبت  با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
     return back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Product  $product
     * @return \Illuminate\Http\Response
     */
    public function show(Product $product)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Product  $product
     * @return \Illuminate\Http\Response
     */
    public function edit(Product $product)
    {
        $action = URL::route('admin.product.update', ['product' => $product->id]);
        $title='ویرایش محصول';
        SEOMeta::setTitle( $title);
        return view('admin.product.create',compact(['product','action','title']));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \App\Http\Requests\UpdateProductRequest  $request
     * @param  \App\Models\Product  $product
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateProductRequest $request, Product $product)
    {
        $request->merge(['price' => remove(',',$request->price)]);
        $request->merge(['price_buy' => remove(',',$request->price_buy)]);
        if($request->hasFile('picture'))
        {
        $request->merge(['pic' => storeFile($request->picture,'uploads/product/')]);
        }
        $product->update($request->all());
        if($request->hasFile('file'))
        {
            if(!empty($product->file))
            {
                $product->file()->update([
                    'file' =>storeFile($request->file,'product',1)
                ]);
            }
            else
            {
                $product->file()->create([
                    'file' =>storeFile($request->file,'product',1)
                ]); 
            }
           
        }
        alert()->success('ویرایش  با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return redirect(route('admin.product.index'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Product  $product
     * @return \Illuminate\Http\Response
     */
    public function destroy(Product $product)
    {
        $product->delete();
        alert()->success('حذف اطلاعات با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return back();
    }
    public function export()
    {
        return Excel::download(new ProductExport, 'product.xlsx');
    }
    public function download(Product $product)
    {
        $pathToFile = storage_path('app/' . $product->file->file);
        return response()->download($pathToFile);
    }
}
