<?php

namespace App\Http\Controllers\Admin;

use App\Models\Program;
use App\Http\Controllers\Controller;
use App\Http\Requests\StoreProgramRequest;
use App\Http\Requests\UpdateProgramRequest;
use App\Models\ProgramDay;
use App\Models\Service;
use Artesaos\SEOTools\Facades\SEOMeta;
use Illuminate\Support\Facades\URL;

class ProgramController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Service $service)
    {
        $title = 'لیست نوبت های خدمت ' . ' ' . $service->name;
        $title2 = 'افزودن نوبت برای خدمت' . ' ' . $service->name;
        SEOMeta::setTitle($title);
        $programs = Program::query();
        $programs->where('service_id', $service->id);
        if ($keyword = request('search')) {
            $programs->where('name', 'LIKE', "%{$keyword}%");
        }
        $programs = $programs->latest()->paginate(25);
        $action = URL::route('admin.service.program.store', $service->id);
        return view('admin.program.index', compact('programs', 'title', 'action', 'title2', 'service'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \App\Http\Requests\StoreProgramRequest  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreProgramRequest $request, Service $service)
    {
        $program = $service->programs()->create($request->all());

        $startTime = strtotime($program->time_start);   /* Find the timestamp of start time */
        $endTime = strtotime($program->time_end);       /* Find the timestamp of end time */
        $input = array();
        /* Run a loop from start timestamp to end timestamp */
        for ($i = $startTime; $i < $endTime; $i += $request->duration * 60) {
            $program_days = ProgramDay::create([
                'day' => $request->day,
                'program_id' => $program->id,
                'service_id' => $service->id,
                'time_start' => date("H:i", $i),
                'time_end' => date("H:i", ($i + $request->duration * 60)),
                'is_vip' => $request->is_vip,
                'capacity' => 1,
                'status' => $request->status,

            ]);
        }


        alert()->success('ثبت  با موفقیت انجام شد', 'پیغام سیستم')->persistent('تایید');
        return back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Program  $program
     * @return \Illuminate\Http\Response
     */
    public function show(Program $program)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Program  $program
     * @return \Illuminate\Http\Response
     */
    public function edit(Program $program)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \App\Http\Requests\UpdateProgramRequest  $request
     * @param  \App\Models\Program  $program
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateProgramRequest $request, Service $service, Program $program)
    {
        $program->update($request->all());
        
        $startTime = strtotime($program->time_start);   /* Find the timestamp of start time */
        $endTime = strtotime($program->time_end);       /* Find the timestamp of end time */
        $p=ProgramDay::where('program_id',$program->id)->delete();
        for ($i = $startTime; $i < $endTime; $i += $request->duration * 60) {
            $program_days = ProgramDay::create([
                'day' => $request->day,
                'program_id' => $program->id,
                'service_id' => $service->id,
                'time_start' => date("H:i", $i),
                'time_end' => date("H:i", ($i + $request->duration * 60)),
                'is_vip' => $request->is_vip,
                'capacity' => 1,
                'status' => $request->status,

            ]);
        }
        alert()->success('ثبت  با موفقیت انجام شد', 'پیغام سیستم')->persistent('تایید');
        return back();
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Program  $program
     * @return \Illuminate\Http\Response
     */
    public function destroy(Service $service,Program $program)
    {
        $program->programDays()->delete();
        $program->delete();
        alert()->success('حذف اطلاعات با موفقیت انجام شد', 'پیغام سیستم')->persistent('تایید');
        return back();
    }
}
