<?php

namespace App\Http\Controllers\Admin;

use App\Models\ProgramDay;
use App\Http\Controllers\Controller;
use App\Http\Requests\StoreProgramDayRequest;
use App\Http\Requests\UpdateProgramDayRequest;
use App\Models\Program;
use Artesaos\SEOTools\Facades\SEOMeta;
use Illuminate\Support\Facades\URL;

class ProgramDayController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Program $program)
    {
        $title = 'لیست  نوبت' . ' ' . config('value.days')[$program->day].' '.$program->service->name;
        SEOMeta::setTitle($title);
        $programDays = ProgramDay::query();
        $programDays->where('program_id', $program->id);
        if ($keyword = request('search')) {
            $programDays->where('name', 'LIKE', "%{$keyword}%");
        }
        $programDays = $programDays->OrderBy('time_start')->paginate(25);
        $action = URL::route('admin.program.programDay.store', $program->id);
        return view('admin.program.days', compact('programDays', 'title', 'action', 'program'));
    }


    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \App\Http\Requests\StoreProgramDayRequest  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreProgramDayRequest $request, Program $program)
    {
        $program->programDays()->update([
            'status'=>0,
            'is_vip'=>0
        ]);
        if(isset($request->capacity))
        {
        foreach ($request->capacity as $key => $value) {

            $programDay = ProgramDay::find($key);
            $a = $programDay->update([
                'status' =>@$request->status[$key],
                'is_vip'=> @$request->is_vip[$key],
                'capacity'=>$value,
            ]);
           
        }
    }
        alert()->success('  وضعیت  موجودی با موفقیت تغییر یافت', 'پیغام سیستم')->persistent('تایید');
        return back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\ProgramDay  $programDay
     * @return \Illuminate\Http\Response
     */
    public function show(ProgramDay $programDay)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\ProgramDay  $programDay
     * @return \Illuminate\Http\Response
     */
    public function edit(ProgramDay $programDay)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \App\Http\Requests\UpdateProgramDayRequest  $request
     * @param  \App\Models\ProgramDay  $programDay
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateProgramDayRequest $request, Program $program, ProgramDay $programDay)
    {
        $programDay->update($request->all());
        alert()->success('ثبت  با موفقیت انجام شد', 'پیغام سیستم')->persistent('تایید');
        return back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\ProgramDay  $programDay
     * @return \Illuminate\Http\Response
     */
    public function destroy(Program $program, ProgramDay $programDay)
    {
        $programDay->delete();
        alert()->success('حذف اطلاعات با موفقیت انجام شد', 'پیغام سیستم')->persistent('تایید');
        return back();
    }
}
