<?php

namespace App\Http\Controllers\Admin;

use App\Models\Service;
use App\Http\Controllers\Controller;
use App\Http\Requests\StoreServiceRequest;
use App\Http\Requests\UpdateServiceRequest;
use App\Models\Category;
use Artesaos\SEOTools\Facades\SEOMeta;
use Illuminate\Support\Facades\URL;

class ServiceController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
       $this->middleware('permission:admin-service-list', ['only' => ['index']]);
       $this->middleware('permission:admin-service-create', ['only' => ['create','store']]);
       $this->middleware('permission:admin-service-edit', ['only' => ['edit','update']]);
       $this->middleware('permission:admin-service-delete', ['only' => ['destroy']]);
    }
    public function index()
    {
        $title='لیست خدمات';
        SEOMeta::setTitle($title);
        $services = Service::query();
        if ($keyword = request('search')) {
            $services->where('name', 'LIKE', "%{$keyword}%")->orWhere('code', 'LIKE', "%{$keyword}%");
        }
        $services = $services->latest()->paginate(25);
       return view('admin.service.index',compact('services','title'));
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $service = new Service;
        $action = URL::route('admin.service.store');
        $title='افزودن خدمت';
        SEOMeta::setTitle( $title);
        $categoreis = Category::get();
        $categoreis=$categoreis->groupBy('category_id');
        return view('admin.service.create',compact(['service','action','title','categoreis']));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \App\Http\Requests\StoreServiceRequest  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreServiceRequest $request)
    {
       
        if($request->hasFile('picture'))
        {
        $request->merge(['pic_main' => storeFile($request->picture,'uploads/service/')]);
        }
        $service=Service::create($request->all());
    alert()->success('ثبت  با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
     return back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Service  $service
     * @return \Illuminate\Http\Response
     */
    public function show(Service $service)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Service  $service
     * @return \Illuminate\Http\Response
     */
    public function edit(Service $service)
    {
        $action = URL::route('admin.service.update', ['service' => $service->id]);
        $title='ویرایش محصول';
        SEOMeta::setTitle( $title);
        $categoreis = Category::get();
        $categoreis=$categoreis->groupBy('category_id');
        return view('admin.service.create',compact(['service','action','title','categoreis']));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \App\Http\Requests\UpdateServiceRequest  $request
     * @param  \App\Models\Service  $service
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateServiceRequest $request, Service $service)
    {
        if($request->hasFile('picture'))
        {
        $request->merge(['pic_main' => storeFile($request->picture,'uploads/service/')]);
        }
        $service->update($request->all());
        if($request->hasFile('file'))
        {
            if(!empty($service->file))
            {
                $service->file()->update([
                    'file' =>storeFile($request->file,'service',1)
                ]);
            }
            else
            {
                $service->file()->create([
                    'file' =>storeFile($request->file,'service',1)
                ]); 
            }
           
        }
        alert()->success('ویرایش  با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return redirect(route('admin.service.index'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Service  $service
     * @return \Illuminate\Http\Response
     */
    public function destroy(Service $service)
    {
        $service->delete();
        alert()->success('حذف اطلاعات با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return back();
    }
}
