<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Gateway;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\Storage;
use Artesaos\SEOTools\Facades\SEOMeta;

class SettingController extends Controller
{
    public function __construct()
    {
       $this->middleware('permission:admin-setting-sms', ['only' => ['showSms','updateSms']]);
       $this->middleware('permission:admin-setting-index', ['only' => ['showInformation','updateInformation']]);
       $this->middleware('permission:admin-setting-gateways', ['only' => ['showGateways','updateGateways']]);

    }
    public function showInformation()
    {
        SEOMeta::setTitle('تنظیمات کلی نرم افزار');
        return view('admin.settings.setting');
    }

    public function updateInformation(Request $request)
    {
       // $this->authorize('settings.information');

        $informations = $request->except(['info_icon', 'info_logo']);

        $except = [
            'personalpay',
        ];
        $uploads=array('logo_dark_mobile','logo_dark_desktop','logo_light_mobile','logo_light_desktop','banner_image','faveicon','comment_user_1_pic','comment_user_2_pic','comment_user_3_pic');
        foreach($uploads as $upload)
        {
            if ($request->hasFile($upload)) {

                $imageName = time() .'_'.$upload. '.' . $request->$upload->getClientOriginalExtension();
                $request->$upload->move('uploads/', $imageName);
    
                $old_icon = option($upload);
    
                if ($old_icon) {
                    Storage::disk('public')->delete($old_icon);
                }
    
                $informations[$upload] = '/uploads/' . $imageName;
            }
        }
        foreach ($informations as $information => $value) {
            option_update($information, $value);
        }
        foreach ($except as $option) {
            if ($request->$option) {
                option_update($option, 'on');
            } else {
                option_update($option, 'off');
            }
        }

        alert()->success('ثبت  اطلاعات با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return back();

       
    }

    public function showSocials()
    {
        $this->authorize('settings.socials');

        return view('back.settings.socials');
    }

    public function updateSocials(Request $request)
    {
        $this->authorize('settings.socials');

        $socials = $request->all();

        foreach ($socials as $social => $value) {
            option_update($social, $value);
        }

        return response('success');
    }

    public function showGateways()
    {
      //  $this->authorize('settings.gateway');

      SEOMeta::setTitle('تنظیمات درگاه پرداخت');

        $gateways = Gateway::get();

        return view('admin.settings.gateways', compact('gateways'));
    }

    public function updateGateways(Request $request)
    {
     //   $this->authorize('settings.gateway');

        $active_ids = [];

        if ($request->gateways) {
            foreach ($request->gateways as $id => $request_gateway) {
                if (!isset($request_gateway['is_active'])) {
                    continue;
                }

                $active_ids[] = $id;

                $gateway = Gateway::find($id);

                $gateway->update([
                    'name'        => $request_gateway['name'],
                    'ordering'    => $request_gateway['ordering'],
                    'is_active'   => true,
                ]);

                foreach ($request_gateway['configs'] as $key => $value) {
                    $gateway->configs()->updateOrCreate(
                        [
                            'key' => $key
                        ],
                        [
                            'value' => $value
                        ]
                    );
                }
            }
        }

        Gateway::whereNotIn('id', $active_ids)->update([
            'is_active' => false
        ]);

        alert()->success('ثبت اطلاعات با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return back();
    }

   

  

    public function showSms()
    {
       // $this->authorize('settings.sms');
       SEOMeta::setTitle('تنظیمات پیام کوتاه');
        return view('admin.settings.sms');
    }

    public function updateSms(Request $request)
    {
       

        $except = [
            'sms_on_user_register',
            'sms_send_new_factor',
            'sms_installment',
            'sms_remember_factor',
            'sms_ok_factor_user',
            'sms_ok_factor_manager',
            'forgot_sms',
            'sms_ticket_manager',
            'sms_ticket_user'
        ];

        $sms = $request->except($except);

        foreach ($sms as $key => $value) {
            option_update($key, $value);
        }

        foreach ($except as $option) {
            if ($request->$option) {
                option_update($option, 'on');
            } else {
                option_update($option, 'off');
            }
        }

        alert()->success('ثبت اطلاعات با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return back();
    }
}
