<?php

namespace App\Http\Controllers\Admin;

use App\Models\Tariff;
use App\Http\Controllers\Controller;
use App\Http\Requests\StoreTariffRequest;
use App\Http\Requests\UpdateTariffRequest;
use App\Models\Service;
use App\Models\User;
use Artesaos\SEOTools\Facades\SEOMeta;
use Illuminate\Support\Facades\URL;

class TariffController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Service $service)
    { 
        $title='لیست تعرفه های'.' '.$service->name;
        $title2='افزودن تعرفه برای خدمت'.' '.$service->name;
        SEOMeta::setTitle($title);
        $tariffs = Tariff::query();
        $tariffs->where('service_id',$service->id);
        if ($keyword = request('search')) {
            $tariffs->where('name', 'LIKE', "%{$keyword}%");
        }
        $tariffs = $tariffs->latest()->paginate(25);
        $action = URL::route('admin.service.tariff.store',$service->id);
        $persenels = User::where('persenel','1')->get();
       return view('admin.tariff.index',compact('tariffs','title','action','persenels','title2','service'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Service $service)
    {
        $tariff = new Tariff;
        $action = URL::route('admin.service.tariff.store',$service->id);
        $title='افزودن تعرفه برای خدمت'.' '.$service->name;
        SEOMeta::setTitle( $title);
        $persenels = User::where('type','persenel')->get();
        return view('admin.service.create',compact(['service','action','title','persenels','tariff']));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \App\Http\Requests\StoreServiceTariffRequest  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreTariffRequest $request,Service $service)
    {
        $tariff = $service->tariffs()->create($request->all());
    alert()->success('ثبت  با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
     return back();
    }

    
    /**
     * Update the specified resource in storage.
     *
     * @param  \App\Http\Requests\UpdateServiceTariffRequest  $request
     * @param  \App\Models\ServiceTariff  $serviceTariff
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateTariffRequest $request, Service $service,Tariff $tariff)
    {
        $tariff->update($request->all());
    alert()->success('ثبت  با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
     return back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\ServiceTariff  $serviceTariff
     * @return \Illuminate\Http\Response
     */
    public function destroy(Service $service,Tariff $tariff)
    {
        $tariff->delete();
        alert()->success('حذف اطلاعات با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return back();
    }
}
