<?php

namespace App\Http\Controllers\Admin;
use App\Http\Controllers\Controller;
use App\Models\TicketCategory;
use App\Http\Requests\StoreTicketCategoryRequest;
use App\Http\Requests\UpdateTicketCategoryRequest;
use App\Models\User;
use URL;
use Artesaos\SEOTools\Facades\SEOMeta;
class TicketCategoryController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
       $this->middleware('permission:admin-department-index', ['only' => ['index','create','store','edit','update','destory']]);
    }
    public function index()
    {
        $ticketCategory = TicketCategory::query();
     
        $ticketCategory = $ticketCategory->latest()->paginate(25);
      
        return view('admin.ticketCategory.index', compact('ticketCategory'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $ticketCategory = new TicketCategory();
        $action = URL::route('admin.ticketCategory.store');
        $title = 'افزودن دپارتمان';
        $users=User::where('type', 'admin')->get();
        SEOMeta::setTitle($title);
        return view('admin.ticketCategory.create', compact('ticketCategory', 'action', 'title','users'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \App\Http\Requests\StoreTicketCategoryRequest  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreTicketCategoryRequest $request)
    {
        $this->validate($request, [
            'name'     => 'required|min:3',
        ]);
        $ticketCategory=TicketCategory::create([
            'name'=>$request->name,
            'color'=>$request->color,
        ]);
        $ticketCategory->users()->sync($request->users);
    alert()->success('ثبت  با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
     return back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\TicketCategory  $ticketCategory
     * @return \Illuminate\Http\Response
     */
    public function show(TicketCategory $ticketCategory)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\TicketCategory  $ticketCategory
     * @return \Illuminate\Http\Response
     */
    public function edit(TicketCategory $ticketCategory)
    {
        $action = URL::route('admin.ticketCategory.update', ['ticketCategory' => $ticketCategory->id]);
        $title='ویرایش دپارتمان';
        $users=User::where('type', 'admin')->get();
         SEOMeta::setTitle($title);
        return view('admin.ticketCategory.create',compact(['ticketCategory','action','title','users']));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \App\Http\Requests\UpdateTicketCategoryRequest  $request
     * @param  \App\Models\TicketCategory  $ticketCategory
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateTicketCategoryRequest $request, TicketCategory $ticketCategory)
    {
        $this->validate($request, [
            'name'     => 'required|min:3',
        ]);
        $ticketCategory->update([
            'name'=>$request->name,
            'color'=>$request->color,
        ]);
        $ticketCategory->users()->sync($request->users);
        alert()->success('ویرایش  با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\TicketCategory  $ticketCategory
     * @return \Illuminate\Http\Response
     */
    public function destroy(TicketCategory $ticketCategory)
    {
        $ticketCategory->delete();
        alert()->success('حذف با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return back();
    }
}
