<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\TicketComment;
use App\Http\Requests\StoreTicketCommentRequest;
use App\Http\Requests\UpdateTicketCommentRequest;
use App\Models\Ticket;
use App\Notifications\Sms\TicketUser;
use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Facades\Storage;

class TicketCommentController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \App\Http\Requests\StoreTicketCommentRequest  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreTicketCommentRequest $request, Ticket $ticket)
    {
        $this->validate($request, [
            'content'     => 'required|min:6',
        ]);
        $ticketComment = new TicketComment();
        $ticketComment->content = $request->content;

        $ticketComment->user_id = auth()->user()->id;
        $ticketComment->ticket_id = $ticket->id;
        $ticketComment->save();
        $ticket->status_id = $request->status_id;
        $ticket->admin_id = auth()->user()->id;
        $ticket->save();
       
        if ($request->has('attach')) {
          
            foreach ($request->attach as $key => $value) {
                $ticketComment->files()->create([
                    'file' => $value,
                ]);
            }
            
        }
        if ($request->has('audio')) {
            foreach ($request->audio as $key => $value) {
            $ticketComment->files()->create([
                'file' => $value,
                'type'=> 'audio',
            ]);
         }
        }
        if (option('sms_ticket_user', 'off') == 'on') {
            Notification::send($ticket->user, new TicketUser($ticket));
        }
        return redirect()->route('admin.ticket.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\TicketComment  $ticketComment
     * @return \Illuminate\Http\Response
     */
    public function show(TicketComment $ticketComment)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\TicketComment  $ticketComment
     * @return \Illuminate\Http\Response
     */
    public function edit(TicketComment $ticketComment)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \App\Http\Requests\UpdateTicketCommentRequest  $request
     * @param  \App\Models\TicketComment  $ticketComment
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateTicketCommentRequest $request, TicketComment $ticketComment)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\TicketComment  $ticketComment
     * @return \Illuminate\Http\Response
     */
    public function destroy(TicketComment $ticketComment)
    {
        //
    }
    public function download(TicketComment $ticketcomment)
    {
        $pathToFile = storage_path('app/ticket/' . $ticketcomment->file);
        return response()->download($pathToFile);
    }
    public function audio(TicketComment $ticketcomment)
    {
        $path = storage_path('app/ticket/' . $ticketcomment->file);
        return  response()->file( $path );
    }
}
