<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Ticket;
use App\Http\Requests\StoreTicketRequest;
use App\Http\Requests\UpdateTicketRequest;
use App\Models\TicketPriority;
use App\Models\Status;
use App\Models\TicketCategory;
use App\Models\TicketCommentFile;
use App\Models\TicketStatus;
use App\Models\User;
use Illuminate\Http\Request;
use URL;
use App\Notifications\Sms\TicketManager;
use App\Notifications\Sms\TicketUser;
use Illuminate\Support\Facades\Notification;

class TicketController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('permission:admin-ticket-index', ['only' => ['index']]);
        $this->middleware('permission:admin-ticket-create', ['only' => ['create', 'store']]);
        $this->middleware('permission:admin-ticket-show', ['only' => ['show', 'download']]);
    }
    public function index()
    {
       
        $array = auth()->user()->departments->pluck('id')->toArray();
        $tickets = Ticket::query();
        $tickets->where(function ($query) use ($array) {$query->whereNull('admin_id')->WhereIN('category_id', $array);
        })->Orwhere(function ($query) {
            $query->where('admin_id', auth()->user()->id);
        });
        if ($keyword = request('search')) {
            $tickets->where('subject', 'LIKE', "%{$keyword}%")->orWhere('id', 'LIKE', "{$keyword}");
        }
        
        $tickets = $tickets->orderby('updated_at', 'DESC')->paginate(25);
        $status = TicketStatus::all();
        return view('admin.ticket.index', compact('tickets', 'status'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $ticket = new Ticket();
        $action = URL::route('admin.ticket.store');
        $title = 'افزودن تیکت';
        $priority = TicketPriority::all();
        $category = TicketCategory::all();
        $statuses = TicketStatus::all();
        $users = User::where('type', 'user')->get();
        return view('admin.ticket.create', compact(['ticket', 'action', 'title', 'priority', 'category', 'statuses'], 'users'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \App\Http\Requests\StoreTicketRequest  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreTicketRequest $request)
    {
        $this->validate($request, [
            'name'     => 'required|min:3',
            'content'     => 'required|min:6',
            'priority_id' => 'required|exists:ticket_priorities,id',
            'category_id' => 'required|exists:ticket_categories,id',
        ]);

        $ticket = new Ticket();
        $ticket->subject = $request->name;
        $ticket->content = $request->content;
        $ticket->priority_id = $request->priority_id;
        $ticket->category_id = $request->category_id;
        $ticket->createby = 'admin';
        $ticket->status_id = $request->status_id;;

        $ticket->admin_id = auth()->user()->id;
        $ticket->user_id = $request->user_id;
        $ticket->save();

        if ($request->has('attach')) {
            foreach ($request->attach as $key => $value) {
                $ticket->files()->create([
                    'file' => $value,
                ]);
            }
        }
        if ($request->has('audio')) {
            foreach ($request->audio as $key => $value) {
                $ticket->files()->create([
                    'file' => $value,
                    'type' => 'audio',
                ]);
            }
        }
        if (option('sms_ticket_user', 'off') == 'on') {
            Notification::send($ticket->user, new TicketUser($ticket));
        }
        return redirect()->route('admin.ticket.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Ticket  $ticket
     * @return \Illuminate\Http\Response
     */
    public function show(Ticket $ticket)
    {
        $priority = TicketPriority::all();
        $category = TicketCategory::all();
        $statuses = TicketStatus::all();
        return view('admin.ticket.show', compact(['ticket', 'priority', 'category', 'statuses']));
    }
    public function download(TicketCommentFile $ticketcommentfile)
    {
        $pathToFile = storage_path('app/ticket/' . $ticketcommentfile->file);
        return response()->download($pathToFile);
    }
    public function audio(TicketCommentFile $ticketcommentfile)
    {
        $path = storage_path('app/ticket/' . $ticketcommentfile->file);
        return  response()->file($path);
    }
    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Ticket  $ticket
     * @return \Illuminate\Http\Response
     */
    public function edit(Ticket $ticket)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \App\Http\Requests\UpdateTicketRequest  $request
     * @param  \App\Models\Ticket  $ticket
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateTicketRequest $request, Ticket $ticket)
    {
        $ticket->status_id = $request->status_id;;
        $ticket->save();
        return redirect()->route('admin.ticket.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Ticket  $ticket
     * @return \Illuminate\Http\Response
     */
    public function destroy(Ticket $ticket)
    {
        $ticket->comments()->delete();
        $ticket->delete();
        alert()->success('حذف با موفقیت انجام شد', 'پیغام سیستم')->persistent('تایید');
        return back();
    }
}
