<?php

namespace App\Http\Controllers\Admin;

use App\Events\OkPardakht;
use App\Models\Transaction;
use App\Http\Controllers\Controller;
use App\Http\Requests\StoreTransactionRequest;
use App\Http\Requests\UpdateTransactionRequest;
use App\Models\Factor;
use App\Models\Installment;
use App\Notifications\Sms\OkFactorUser;
use Artesaos\SEOTools\Facades\SEOMeta;
use Illuminate\Support\Facades\Notification;

class TransactionController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
          $this->middleware('permission:admin-payment-index', ['only' => ['index']]);
          $this->middleware('permission:admin-factor-payment', ['only' => ['store']]);
          $this->middleware('permission:admin-fish-index', ['only' => ['fish']]);
          $this->middleware('permission:admin-fish-update', ['only' => ['changestatus']]);
        
    }
    public function index()
    {
        SEOMeta::setTitle('لیست کامل پرداخت های موفق و ناموفق ');
        $transactions = Transaction::query();
        if ($keyword = request('search')) {
            $transactions->where('id', 'LIKE', "{$keyword}");
        }
        $transactions = $transactions->latest()->paginate(25);
       return view('admin.transaction.index',compact('transactions'));
    }
    public function fish()
    {
        SEOMeta::setTitle('لیست فیش های بانکی تایید نشده');
        $transactions = Transaction::query();
        $transactions = $transactions->where('type','فیش بانکی')->where('status',0)->latest()->paginate(25);
       return view('admin.transaction.fish',compact('transactions'));
    }
    public function changestatus(StoreTransactionRequest $request,Transaction $transaction)
    {
        $transaction->status = $request->status;
        $transaction->save();
        event(new OkPardakht($transaction));
        return back();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \App\Http\Requests\StoreTransactionRequest  $request
     * @return \Illuminate\Http\Response
     */
    public function store(StoreTransactionRequest $request)
    {
       

        $factor=Factor::find($request->factor);
        if(str_replace(',','',$request->price) > notpaymentfactor($factor))
        {
            alert()->error('مبلغ پرداختی از مبلغ باقی مانده بیشتر می باشد','پیغام سیستم')->persistent('تایید');
            return back()->withInput(($request->all()));
        }
        $request->request->add(['user_id' => $factor->user_id]);
        $request->request->add(['transid' => rand(10000000,99999999)]); //add request
        $request->request->add(['status' => '1']); //add request
        $transaction = $factor->transactions()->create($request->all());
        if (option('sms_ok_factor_user', 'off') == 'on') {
            Notification::send($transaction->user, new OkFactorUser($transaction));
        }
        return back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Transaction  $transaction
     * @return \Illuminate\Http\Response
     */
    public function show(Transaction $transaction)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Transaction  $transaction
     * @return \Illuminate\Http\Response
     */
    public function edit(Transaction $transaction)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \App\Http\Requests\UpdateTransactionRequest  $request
     * @param  \App\Models\Transaction  $transaction
     * @return \Illuminate\Http\Response
     */
    public function update(UpdateTransactionRequest $request, Transaction $transaction)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Transaction  $transaction
     * @return \Illuminate\Http\Response
     */
    public function destroy(Transaction $transaction)
    {
        if($transaction->installment)
        {
            $installments=$transaction->installments;
            foreach ($installments as $installment)
            {
                $installment->status=0;
                $installment->save(); 
            }
            
        }
       $transaction->delete();
       return back();
    }
}
