<?php

namespace App\Http\Controllers\Admin;
use App\Http\Controllers\Controller;
use App\Models\User;
use App\Notifications\Sms\NewUser;
use Spatie\Permission\Models\Role;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use URL;
use Illuminate\Support\Facades\Notification;
use Artesaos\SEOTools\Facades\SEOMeta;
use Maatwebsite\Excel\Facades\Excel;
use App\Exports\UsersExport;
use App\Repository\UserRepositoryInterface;

class UserController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */


    public function __construct()
    {
        $this->middleware('permission:admin-user-list', ['only' => ['index']]);
       $this->middleware('permission:admin-user-create', ['only' => ['create','store']]);
       $this->middleware('permission:admin-user-edit', ['only' => ['edit','update','export']]);
       $this->middleware('permission:admin-user-delete', ['only' => ['destroy']]);
       $this->middleware('permission:admin-user-factor', ['only' => ['factor']]);
       $this->middleware('permission:admin-user-payment', ['only' => ['transaction']]);
    }
    public function index()
    {
        SEOMeta::setTitle('لیست کاربران');
        $users = User::query();
        $users->where('admin','1');
        if ($keyword = request('search')) {
            $users->where('name', 'LIKE', "%{$keyword}%")->orWhere('family', 'LIKE', "%{$keyword}%");
        }
        $users = $users->latest()->paginate(25);
       return view('admin.user.index',compact('users'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $roles = Role::get();
        $userRole = array();
        $user = new User;
        $action = URL::route('admin.user.store');
        $title='افزودن کاربر/ مشتری';
        SEOMeta::setTitle($title);
        return view('admin.user.create',compact(['user','action','title','roles','userRole']));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'family' => ['required', 'string', 'max:255'],
            'mobile' => ['required', 'string', 'max:255', 'unique:users'],
            'email'=>['nullable','string','unique:users'],
            'status'=>['nullable','boolean'],
        ]);
        $user=User::create([
            'name' => $data['name'],
            'family' => $data['family'],
            'password' => Hash::make(faTOen($data['mobile'])),
            'mobile' => faTOen($data['mobile']),
            'email'=> $data['email'],
            'status'=> $data['status'],
            'type'=> 'admin',
            'admin'=>1,
            'persenel'=>1,
            'customer'=>1,
            'codemeli'=>$request->codemeli,
            'address'=>$request->address,
        ]);
        if (option('sms_on_user_register', 'off') == 'on') {
            Notification::send($user, new NewUser($user));
        }
        $user->assignRole($request->input('roles'));
    alert()->success('ثبت  با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
     return back();
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\User  $user
     * @return \Illuminate\Http\Response
     */
    public function show(User $user)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\User  $user
     * @return \Illuminate\Http\Response
     */
    public function edit(User $user)
    {
        $roles = Role::get();
        if($user->type=='admin')
        {
        $userRole = $user->roles->pluck('name','name')->all();
        }
        else
        {
            $userRole = array();
        }

        $action = URL::route('admin.user.update', ['user' => $user->id]);
        $title='ویرایش کاربر / مشتری';
         SEOMeta::setTitle($title);
        return view('admin.user.create',compact(['user','action','title','roles','userRole']));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\User  $user
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, User $user)
    {
        $data = $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'family' => ['required', 'string', 'max:255'],
            'mobile' => ['required', 'string', 'max:255'],
            'email'=>['nullable','string'],
            'status'=>['nullable','boolean'],
        ]);

        $user->update([
            'name' => $data['name'],
            'family' => $data['family'],
            'mobile' => faTOen($data['mobile']),
            'email'=> $data['email'],
            'status'=> $data['status'],
            'codemeli'=>$request->codemeli,
            'address'=>$request->address,
        ]);
        $user->syncRoles($request->input('roles'));
        alert()->success('ویرایش  با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return redirect(route('admin.user.index'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\User  $user
     * @return \Illuminate\Http\Response
     */
    public function destroy(User $user)
    {
        $user->delete();
        alert()->success('حذف با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return back();
    }
    public function userapi(Request $request)
    {
        $data = $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'family' => ['required', 'string', 'max:255'],
            'mobile' => ['required', 'string', 'max:255', 'unique:users'],
        ]);
        $user=User::create([
            'name' => $data['name'],
            'family' => $data['family'],
            'password' => Hash::make(faTOen($data['mobile'])),
            'mobile' => faTOen($data['mobile']),
            'status'=> $request['status'],
            'type'=> 'user',
        ]);
        return response(['user_id' => $user->id,'name'=>$user->nf]);
    }
    public function profile()
    {
       return view('admin.profile.profile');
    }
    public function changepassword()
    {
      return view('admin.profile.changepassword');
    }
    public function twofactor()
    {
       return view('Admin.profile.twofactor');
    }
    public function factor(User $user)
    {
        $factors=$user->factors;
        $users = User::where('type', 'user')->get();
        $factors=$factors->SortByDesc('updated_at')->paginate(50);
        return view('admin.factor.index',compact('factors','user','users'));
    }
    public function transaction(User $user)
    {
        $transactions=$user->transactions->where('status', 1);
        $transactions=$transactions->SortByDesc('updated_at')->paginate(50);
        return view('admin.transaction.index',compact('transactions','user'));
    }

    public function export()
    {
        return Excel::download(new UsersExport, 'users.xlsx');
    }
}
