<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Models\ActiveCode;
use App\Models\User;
use App\Notifications\Sms\VerifyCodeSent;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Facades\Password;

class PasswordResetLinkController extends Controller
{
    public function create()
    {

        if (option('forgot_sms', 'on') == 'off') {
            abort(404);
        }
        return view('auth.forgot-sms');
    }

    public function store(Request $request)
    {
        $request->validate([
            'mobile' => 'required|exists:users,mobile',
            'captcha' => ['required', 'captcha'],
        ]);

        $user = User::where('mobile', $request->mobile)->first();

        $this->sendCode($user);

       return redirect(route('active-code',['mobile' => $user->mobile]));
    }

    public static function sendCode(User $user)
    {
        $verify_code = ActiveCode::where('user_id', $user->id)->latest()->first();

        if ($verify_code) {
            $now = Carbon::now();
            $time = $verify_code->created_at;

            if ($time->diffInSeconds($now) < 120) {
                return;
            }
        }

        // send sms notification to user
        Notification::send($user, new VerifyCodeSent($user));
    }
}
