<?php

namespace App\Http\Controllers;

use App\Models\Baner;
use App\Models\Category;
use App\Models\Factor;
use App\Models\File;
use App\Models\Gateway;
use App\Models\PersonalPay;
use App\Models\Post;
use App\Models\Product;
use App\Models\ProductPay;
use App\Models\ProgramDay;
use App\Models\Reservation;
use App\Models\Service;
use App\Models\Shahr;
use App\Models\Slideshow;
use App\Models\User;
use Artesaos\SEOTools\Facades\SEOTools;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\URL;
use Illuminate\Support\Str;
use Morilog\Jalali\Jalalian;

class HomeController extends Controller
{
    public function index()
    {
        $title = 'صفحه اصلی';
        $description = option('description');
        SEOTools::setTitle($title);
        SEOTools::setDescription($description);
        SEOTools::setCanonical(URL::full());
        SEOTools::opengraph()->addProperty('type', 'mainpage');
        SEOTools::twitter()->setSite('@mahampartoo');
        SEOTools::twitter()->addImage(option('logo'));
        $slideshows = Slideshow::where('active', '1')->get();
        $services = Service::where('status', '1')->latest()->limit(24)->get();

        $posts = Post::where('active', '1')->latest()->limit(12)->get();
        $galleris = Category::where('category_id', '0')->where('type', 'gallery')->get();
        $baners = Baner::all();
        return view('front.index', compact(['slideshows', 'baners', 'services',  'posts', 'galleris']));
    }
    public function blogs()
    {
        $title = 'کلیه مطالب';
        $description = 'کلیه مطالب وب سایت';
        SEOTools::setTitle($title);
        SEOTools::setDescription($description);
        SEOTools::setCanonical(URL::route('blogs'));
        $posts = Post::where('active', '1')->latest()->paginate(option('blog_item_per_page'));
        $title = 'کلیه مطالب';
        return view('front.blogs', compact(['posts', 'title']));
    }
    public function blog(post $post)
    {
        $title = isset($post->title) ? $post->title : $post->name;
        $description = isset($post->description) ? $post->description : Str::limit(strip_tags($post->fullcontent), 250);
        SEOTools::setTitle($title);
        SEOTools::setDescription($description);
        SEOTools::setCanonical(Url::full());

        $catblog = Category::where('type', 'post')->get();
        $posts = Post::where('active', '1')->latest()->limit(4)->get();
        $next = $post->next();
        $previous = $post->previous();
        return view('front.blog', compact(['post', 'previous', 'next', 'catblog', 'posts']));
    }
    public function service(Service $service)
    {
        $title = isset($service->title) ? $service->title : $service->name;
        $description = isset($service->description) ? $service->description : Str::limit(strip_tags($service->fullcontent), 250);
        SEOTools::setTitle($title);
        SEOTools::setDescription($description);
        SEOTools::setCanonical(Url::full());
        $services = Service::where('status', '1')->latest()->limit(3)->get();
        return view('front.service', compact(['service', 'services']));
    }
    public function services()
    {
        $title = 'کلیه محصولات';
        $description = 'کلیه محصولات وب سایت';
        SEOTools::setTitle($title);
        SEOTools::setDescription($description);
        SEOTools::setCanonical(URL::route('services'));

        $services = Service::where('status', '1')->latest()->paginate(option('service_item_per_page'));
        $picheader = '/images/new image/headerImage/headersinglepage.jpg';
        return view('front.services', compact(['services', 'title', 'picheader']));
    }
    public function reserve_page(Service $service, Request $request)
    {
        $title = 'رزرو نوبت';
        $description = 'کلیه محصولات وب سایت';
        SEOTools::setTitle($title);
        SEOTools::setDescription($description);
        SEOTools::setCanonical(URL::route('services'));

        $services = Service::where('status', '1')->latest()->simplePaginate(option('service_item_per_page'));
        $picheader = '/images/new image/headerImage/headersinglepage.jpg';
        $program = ProgramDay::find($request->program);
        $reserve = Reservation::where('user_id', auth()->user()->id)->where('program_id', $request->program)->first();
        $program = ProgramDay::find($request->program);
        if ($reserve) {
           
        } else {
            $reserve = Reservation::create([
                'user_id' => auth()->user()->id,
                'program_id' => $request->program,
                'service_id' => $service->id,
                'date_at' => $request->date,
                'time_at' => $program->time_start,
                'end_at' => $program->time_end,
                'vip' => $program->is_vip,
            ]);
        }
        $expire_at = now()->addMinutes($service->expire_at);
        $expire_at = $expire_at->subMinutes(210);
        return view('front.reserve', compact(['services', 'title', 'program', 'service', 'reserve', 'expire_at']));
    }
    public function galleries()
    {
        $cats = Category::where('parent', '0')->where('type', 'gallery')->get();
        $title = 'گالری تصاویر';
        $description = 'گالری تصاویر';
        SEOTools::setTitle($title);
        SEOTools::setDescription($description);
        SEOTools::setCanonical(URL::route('galleries'));
        return view('front.galleries', compact(['cats', 'title']));
    }
    public function gallery(Category $category)
    {
        $cats = Category::where('parent', $category->id)->get();
        $galleries = $category->galleries;
        $title = 'گالری تصاویر' . ' ' . $category->name;
        $description = 'گالری تصاویر';
        SEOTools::setTitle($title);
        SEOTools::setDescription($description);
        SEOTools::setCanonical(URL::route('gallery', $category->id));
        return view('front.gallery', compact(['cats', 'title', 'galleries']));
    }
    public function invoice(Factor $factor)
    {
        $subfactor = $factor->subfactors;
        $gateways = Gateway::orderBy('ordering', 'ASC')->active();
        return view('factor', compact('factor', 'subfactor', 'gateways'));
    }
    public function print(Factor $factor)
    {
        $subfactor = $factor->subfactors;
        $gateways = Gateway::orderBy('ordering', 'ASC')->active();
        return view('factor.index', compact('factor', 'subfactor'));
    }
    public function product(Product $product)
    {
        if (!$product->status || $product->count == 0)
            return abort(404);
        $gateways = Gateway::orderBy('ordering', 'ASC')->active();
        return view('product', compact('product', 'gateways'));
    }
    public function pay(Factor $factor, Request $request)
    {
        $price = paymentable($factor);
        $gateways = Gateway::active()->pluck('key')->toArray();
        $user = $factor->user;
        $redirecurl = route('invoice', $factor);
        $request->validate([
            'gateway' => 'required|in:wallet,' . implode(',', $gateways)
        ]);
        $gateway = $request->gateway;
        $payment = new PaymentController();
        return $payment->payment($gateway, $price, $user, $redirecurl, $factor);
    }
    public function paypersonal(Request $request)
    {
        $user = User::firstOrCreate(
            ['mobile' =>  $request->mobile],
            [
                'name' => $request->namefamily,
                'password' => Hash::make(faTOen($request['mobile'])),
                'type' => 'user',
            ]
        );
        $gateways = Gateway::active()->pluck('key')->toArray();
        $request->validate([
            'gateway' => 'required|in:wallet,' . implode(',', $gateways),
            'price' => 'required',
            'namefamily' => 'required',
            'name' => 'required',
            'mobile' => 'required',
            'captcha' => ['required', 'captcha'],
        ]);
        $model = PersonalPay::create($request->all());
        $price = remove(',', $request->price);
        $redirecurl = route('pay');
        $gateway = $request->gateway;
        $payment = new PaymentController();
        return $payment->payment($gateway, $price, $user, $redirecurl, $model);
    }
    public function paypage()
    {
        if (option('personalpay', 'off') == 'on') {
            $gateways = Gateway::orderBy('ordering', 'ASC')->active();
            return view('pay', compact('gateways'));
        }
        return abort(404);
    }
    public function product_pay(Product $product, Request $request)
    {
        $gateways = Gateway::active()->pluck('key')->toArray();
        $request->validate([
            'gateway' => 'required|in:wallet,' . implode(',', $gateways),
            'name' => 'required',
            'family' => 'required',
            'mobile' => [
                'required',
                'regex:/^((0)(9){1}[0-9]{9})+$/',
                'min:11',
            ],
            'captcha' => ['required', 'captcha'],
        ]);

        $user = User::firstOrCreate(
            ['mobile' =>  $request->mobile],
            [
                'name' => $request->name,
                'family' => $request->family,
                'password' => Hash::make(faTOen($request['mobile'])),
                'type' => 'user',
            ]
        );
        $price = $product->price * $request->count;
        $request->merge(['price' => $product->price]);
        $request->merge(['user_id' => $user->id]);
        $request->merge(['product_id' => $product->id]);
        $request->merge(['name' => 'خرید مستقیم محصول ' . $product->name]);
        $model = ProductPay::create($request->all());
        $redirecurl = route('product', $product);
        $gateway = $request->gateway;
        $payment = new PaymentController();
        return $payment->payment($gateway, $price, $user, $redirecurl, $model);
    }
    public function download(File $file)
    {
        $pathToFile = storage_path('app/' . $file->file);
        return response()->download($pathToFile);
    }
    public function downloads(File $file)
    {
        return redirect(URL::temporarySignedRoute('download', now()->addMinutes(30), $file));
    }
    public function fish(Request $request)
    {
        $factor = Factor::find($request->factor);

        $request->request->add(['user_id' => $factor->user_id]);
        $request->request->add(['type' => 'فیش بانکی']); //add request
        $request->request->add(['status' => '0']); //add request

        $transaction = $factor->transactions()->create($request->all());
        if ($request->hasFile('file')) {
            $transaction->file()->create([
                'file' => storeFile($request->file, 'fish/', 1)
            ]);
        }

        return back();
    }
    public function city(Request $request)
    {
        $all = Shahr::where('ostan_id', $request->id)->get();
        return response()
            ->json($all);
    }
    public function contact(Request $request)
    {
        return view('front.contact');
    }
    public function about(Request $request)
    {
        return view('front.about');
    }
    public function servicetime(Request $request)
    {
        $result = array();
        $dayInfo = array();
        $day_count = 31;
        if ($request->m > 6 && $request->m < 12) {
            $day_count = 30;
        } else if ($request->m == 12) {
            $day_count = 29;
        }
        $service = Service::find($request->serviceid);
        //حذف زمان های منقضی شده
        $reserv = Reservation::where('expire_at', '<', now())->where('status', 0)->delete();
        $isFirstVisit = false;
        $counter = 1;
        for ($i = 1; $i <= $day_count; $i++) {
            $today = jdate()->format('Y/m/d');
            $max_reservation_date = jdate()->addDays($service->aftherday)->format('Y/m/d');
            $date = $request->y . "/" . str_pad($request->m, 2, '0', STR_PAD_LEFT) . "/" . str_pad($i, 2, '0', STR_PAD_LEFT);
            $dateInfo = (new Jalalian($request->y, $request->m, $i))->toArray();
            $dayInfo['dayCaption'] = config('value.days')[$dateInfo['dayOfWeek']] . str_pad($request->m, 2, '0', STR_PAD_LEFT) . "/" . str_pad($i, 2, '0', STR_PAD_LEFT);
            $dayInfo['shortDate'] = jalalitomiladi($date)->format('Y_m_d');
            $dayInfo['today'] = $date == $today;
            $dayInfo['date'] = $date;
            $dayInfo['isNotInMonth'] = $request->m == jdate()->format('m');
            $dayInfo['hasMultiTimeSections'] = true;
            $isHoliday = false;
            if ($dateInfo['dayOfWeek'] == "6") {
                $isHoliday = true;
            }
            $dayInfo['isHoliday'] = $isHoliday;
            $turnsInfo = array();
            $hasSetTimes = false;
            if (str_replace("/", "", $date) >= jdate()->format("Ymd")) {
                $turns = ProgramDay::where('service_id', $service->id)->where('day', $dateInfo['dayOfWeek'])->where('status', 1)->get();
                $turnsInfo_item = array();
                $turnsInfo = array();

                if (sizeof($turns) > 0) {
                    $hasSetTimes = true;
                    foreach ($turns as $turn) {

                        $check_date_for_timing = $date;

                        $check_time = str_replace("/", "", $check_date_for_timing) . str_replace(":", "", $turn->time_start);

                        if ($check_time >= jdate()->format("YmdHi")) {
                            if (str_replace("/", "", $max_reservation_date) > str_replace("/", "", $check_date_for_timing)) {
                                //در حالت تاریخ دلخواه چک می شود که تاریخ انتخابی با تاریخ روز یکی باشد
                                // خالی بودن زمان چک می شود

                                $data_at = str_replace("/", "_", $check_date_for_timing);
                                $reserv = Reservation::where('service_id', $service->id)->where('time_at', '>=', $turn->time_start)->where('time_at', '<', $turn->time_end)->where('date_at', $data_at)->sum('capacity');
                                if ($turn->capacity >= ($reserv + 1)) {
                                    if ($counter == 1) {
                                        if (!$isFirstVisit) {
                                            $isFirstVisit = true;
                                            $counter++;
                                        }
                                    }
                                    $turnsInfo_item['caption'] = $turn->time_start;
                                    $turnsInfo_item['isVip'] = $turn->is_vip == 1;
                                    $turnsInfo_item['url'] = "/reserve/" . $service->id . "?date=" . str_replace("/", "_", $check_date_for_timing) . "&time=" . str_replace(":", ":", $turn->time_start) . "&program=" .  $turn->id;

                                    $turnsInfo[] = $turnsInfo_item;
                                }
                            }
                        }
                    }
                }
            }

            $dayInfo['isFirstVisit'] = $isFirstVisit;
            if ($isFirstVisit) {
                $isFirstVisit = false;
            }

            $dayInfo['hasSetTimes'] = $hasSetTimes;
            $dayInfo['setTimeItems'] = $turnsInfo;

            $result[] = $dayInfo;
        }
        return response()
            ->json($result);
    }
}
