<?php

namespace App\Http\Controllers;

use App\Models\Ticket;
use App\Http\Requests\StoreTicketRequest;
use App\Models\TicketCategory;
use App\Models\TicketCommentFile;
use App\Models\TicketStatus;
use App\Models\TicketPriority;
use App\Http\Requests\StoreTicketCommentRequest;
use App\Models\TicketComment;
use App\Notifications\Sms\TicketManager;
use Illuminate\Support\Facades\Notification;
use URL;

class PanelController extends Controller
{
    public function factorsindex()
    {
        $factors = auth()->user()->factors;
        $factors = $factors->paginate(25);
        return view('panel.factors.index', compact('factors'));
    }
    public function installments()
    {
        $factors = auth()->user()->installments;
        $factors = $factors->paginate(25);
        return view('panel.installments.index', compact('factors'));
    }
    public function transaction()
    {
        $factors = auth()->user()->transactions->where('status','1');
        $factors = $factors->sortByDesc('updated_at')->paginate(25);
        return view('panel.transaction.index', compact('factors'));
    }
    public function profile()
    {
       
        return view('panel.profile.profile');
    }
    public function changepassword()
    {
       
        return view('panel.profile.changepassword');
    }
    public function ticket_index()
    {
        $tickets = Ticket::query();
        $tickets=$tickets->where('user_id', auth()->user()->id);
        if ($keyword = request('search')) {
            $tickets->where('subject', 'LIKE', "%{$keyword}%")->orWhere('id', 'LIKE', "{$keyword}");
        }
        // else
        // {
        //     $tickets=$tickets->where('status_id', 0);    
        // }
        $tickets = $tickets->orderby('updated_at','DESC')->paginate(25);
        $status = TicketStatus::all();
        return view('panel.ticket.index', compact('tickets','status'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function ticket_create()
    {
        $ticket = new Ticket();
        $action = URL::route('panel.ticket.store');
        $title = 'افزودن تیکت';
        $priority = TicketPriority::all();
        $category = TicketCategory::all();
        $statuses = TicketStatus::all();
        return view('panel.ticket.create', compact(['ticket', 'action', 'title', 'priority', 'category','statuses']));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \App\Http\Requests\StoreTicketRequest  $request
     * @return \Illuminate\Http\Response
     */
    public function ticket_store(StoreTicketRequest $request)
    {
        $this->validate($request, [
            'name'     => 'required|min:3',
            'content'     => 'required|min:6',
            'priority_id' => 'required|exists:ticket_priorities,id',
            'category_id' => 'required|exists:ticket_categories,id',
        ]);

        $ticket = new Ticket();
        $ticket->subject = $request->name;
        $ticket->content = $request->content;
        $ticket->priority_id = $request->priority_id;
        $ticket->category_id = $request->category_id;
        $ticket->createby = 'user';
        $ticket->status_id = 1 ;
        $ticket->user_id = auth()->user()->id;
        $ticket->save();

        if ($request->has('attach')) {
            foreach ($request->attach as $key => $value) {
            $ticket->files()->create([
                'file' => $value,
            ]);
         }
        }
        if ($request->has('audio')) {
            foreach ($request->audio as $key => $value) {
            $ticket->files()->create([
                'file' => $value,
                'type'=> 'audio',
            ]);
         }
        }
        if (option('sms_ticket_manager', 'off') == 'on') {
            Notification::send($ticket->user, new TicketManager($ticket));
        }
        alert()->success('ثبت  تیکت با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return redirect()->route('panel.ticket');
    }
    public function comment_store(StoreTicketCommentRequest $request, Ticket $ticket)
    {
        $this->validate($request, [
            'content'     => 'required|min:6',
        ]);
        $ticketComment = new TicketComment();
        $ticketComment->content = $request->content;
        $ticketComment->user_id = auth()->user()->id;
        $ticketComment->ticket_id = $ticket->id;
        $ticketComment->save();
        $ticket->status_id = 1;
        $ticket->save();
        if ($request->has('attach')) {
          
            foreach ($request->attach as $key => $value) {
                $ticketComment->files()->create([
                    'file' => $value,
                ]);
            }
            
        }
        if ($request->has('audio')) {
            foreach ($request->audio as $key => $value) {
            $ticketComment->files()->create([
                'file' => $value,
                'type'=> 'audio',
            ]);
         }
        }
        if (option('sms_ticket_user', 'off') == 'on') {
            Notification::send($ticket->user, new TicketManager($ticket));
        }
        alert()->success('پاسخ به  تیکت با موفقیت انجام شد','پیغام سیستم')->persistent('تایید');
        return redirect()->route('panel.ticket');
    }
    public function ticket_show(Ticket $ticket)
    {
        if($ticket->user_id==auth()->user()->id) {
        $priority = TicketPriority::all();
        $category = TicketCategory::all();
        $statuses = TicketStatus::all();
        return view('panel.ticket.show', compact(['ticket','priority', 'category','statuses']));
        }
        return abort(403);
    }
    
    public function ticket_download(TicketCommentFile $ticketcommentfile)
    {
        $pathToFile = storage_path('app/ticket/' . $ticketcommentfile->file);
        return response()->download($pathToFile);
    }
    public function ticket_audio(TicketCommentFile $ticketcommentfile)
    {
        $path = storage_path('app/ticket/' . $ticketcommentfile->file);
        return  response()->file( $path );
    }
}
