<?php

namespace App\Jobs;

use App\Models\Factor;
use App\Models\Product;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldBeUnique;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Str;

class ProcessFactor implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;
    public $factor;
    public $tries = 2;
    /**
     * Create a new job instance.
     *
     * @return void
     */
    public function __construct(Factor $factor)
    {
        $this->factor = $factor;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle()
    {
        $factors=Factor::create([
            'name'=>$this->factor->name,
            'code'=>generatecode(),
            'date_factor'=>jdate($this->factor->duedate_factor)->format('Y/m/d'),
            'duedate_factor'=>$this->factor->duedate_factor->addDays($this->factor->period),
            'period'=>$this->factor->period,
            'expire_date'=>jdate($this->factor->duedate_factor)->addDays(10)->format('Y/m/d'),
            'notifications'=>$this->factor->notifications,
            'pardakht'=>$this->factor->pardakht,
            'installment'=>0,
            'themplate'=>$this->factor->themplate,
            'description'=>$this->factor->description,
            'user_id'=>$this->factor->user_id,
            'link'=>Str::random(10),
        ]);

        foreach($this->factor->subfactors as $value)
        {

            if(isset($value['product_id']))
            {
                $product_id=$value['product_id'];
                $product=Product::find($value['product_id']);
                $name=$product->name;
                $price=$product->price;
            }
            else
            {
                $name=$value['name'];
                $product_id=Null;
                $price=$value['price'];
            }
            $factors->subfactors()->create([
                'name'=>$name,
                'count'=>$value['count'],
                'price'=>$price,
                'discount'=>$value['discount'],
                'tax'=>$value['tax'],
                'product_id'=>$product_id,
                'type'=>$value['type'],

            ]);
        }
    }
}
