<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Casts\Attribute;


class Factor extends Model
{
    use HasFactory;
    use \App\Http\Traits\UsesUuid;
    protected $guarded = ['id'];

    protected $casts = [
        'date_factor'=>'datetime',
        'duedate_factor' => 'datetime',
        'expire_date' => 'datetime',
    ];
    protected function dateFactor(): Attribute
    {
        return Attribute::make(
            get: fn ($value) => jdate($value)->format('Y/m/d'),
            set: fn ($value) => jalalitomiladi($value),
        );
    }
    protected function expireDate(): Attribute
    {
        return Attribute::make(
            get: fn ($value) => jdate($value)->format('Y/m/d'),
            set: fn ($value) => jalalitomiladi($value),
        );
    }
    
     
    public function subfactors()
    {
        return $this->hasMany(Subfactor::class);
    }
    public function installments()
    {
        return $this->hasMany(Installment::class);
    }
    public function user()
    {
        return $this->belongsTo(User::class);
    }
    public function transactions()
    {
        return $this->morphMany(Transaction::class, 'transactionable');
    }
    public function file()
    {
        return $this->morphOne(File::class, 'fileable');
    }

}
