<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Casts\Attribute;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Pishran\LaravelPersianSlug\HasPersianSlug;
use Spatie\Sluggable\SlugOptions;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Str;
use Spatie\Sitemap\Tags\Url;

class Post extends Model 
{
    use HasFactory;
    use HasPersianSlug;
    public function getRouteKeyName()
    {
        return 'id';
    }
    public function getSlugOptions(): SlugOptions
    {
        return SlugOptions::create()
            ->generateSlugsFrom('name')
            ->saveSlugsTo('slug')
            ->doNotGenerateSlugsOnUpdate();
    }

    protected $guarded = ['id'];
    public function user()
    {
        return $this->belongsTo(User::class);
    }
    public function categories()
    {
        return $this->morphToMany(Category::class,'catable');
    }
    public function metapost()
    {
       return $this->hasMany(Metapost::class);
    }
   
    public function comments()
    {
        return $this->morphMany(Comment::class, 'commentable');
    }
    public function images()
    {
        return $this->morphMany(Image::class, 'imageable');
    }
    public function questions()
    {
        return $this->morphMany(Question::class, 'questionable');
    }
    public function next(){
        return post::where('id', '>', $this->id)->orderBy('id','asc')->first();

    }
    public  function previous(){
        // get previous  user
        return post::where('id', '<', $this->id)->orderBy('id','desc')->first();

    }
    private function getEstimateReadingTime($content, $wpm = 200) {

        $b = explode(" ",$content);

        $wordCount = count($b);
    
        $minutes = (int) floor($wordCount / $wpm);
        $seconds = (int) floor($wordCount % $wpm / ($wpm / 60));   
    
        if ($minutes === 0) {
            return $seconds." ".Str::of('ثانیه');
        } else {
            return $minutes." ".Str::of('دقیقه');
        }
    
    }
    protected function timeToRead(): Attribute 
    {
        return Attribute::make(
            get: function ($value, $attributes) {

                $value = $this->getEstimateReadingTime($attributes['fullcontent']);

                return $value;

            }
        );
    }    

}
