<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Casts\Attribute;
class Transaction extends Model
{
    use HasFactory;
    protected $guarded = ['id'];
    protected $casts = [
        'payment_at' => 'datetime',
    ];
    const TYPES = [
        'FACTOR' => [
            'key'    => 'App\Models\PersonalPay',
            'string' => 'صفحه پرداخت شخصی ',
        ],
        'PERSONALPAY' => [
            'key'    => 'App\Models\Factor',
            'string' => 'فاکتور  ',
        ],
        'PRODUCTPAY' => [
            'key'    => 'App\Models\ProductPay',
            'string' => 'خرید مستقیم محصول  ',
        ],
    ];
    public function transactionable()
    {
        return $this->morphTo();
    }
    protected function paymentAt(): Attribute
    {
        return Attribute::make(
            set: fn ($value) => jalalitomiladi($value),
        );
    }
    protected function price(): Attribute
    {
        return Attribute::make(
            set: fn ($value) => str_replace(',','',$value),
        );
    }
    public function gateway()
    {
        return $this->belongsTo(Gateway::class);
    }
    public function user()
    {
        return $this->belongsTo(User::class);
    }
    public function installments()
    {
        return $this->hasMany(Installment::class);
    }
    public function type()
    {
        foreach (self::TYPES as $type) {
            if ($this->transactionable_type == $type['key']) {
                return $type['string'];
            }
        }
    }
    public function file()
    {
        return $this->morphOne(File::class, 'fileable');
    }
}
