<?php

namespace App\Notifications\Sms;

use App\Channels\SmsChannel;
use App\Models\installment;
use App\Models\Sms;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;

class RememberInstallment extends Notification implements ShouldQueue
{
    use Queueable;
    public $installment;

    /**
     * Create a new notification instance.
     *
     * @return void
     */
    public function __construct(installment $installment)
    {
        $this->installment = $installment;
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param  mixed  $notifiable
     * @return array
     */
    public function via($notifiable)
    {
        return [SmsChannel::class];
    }

    public function toSms($notifiable)
    {
        return [
            'mobile'  => $notifiable->mobile,
            'data'    => [
                'link' => $this->installment->factor->link,
                'price' =>number_format($this->installment->price).'تومان',
                'name'=>$this->installment->factor->name,
                'nf'=>$notifiable->nf,
                'date'=>jdate($this->installment->due_date)->format('Y-m-d'),
                'id'=>$this->installment->id,
                'modelclass'=>get_class($this->installment)
            ],
            'type'    => Sms::TYPES['INSTALLMENT'],
            'user_id' => $notifiable->id
        ];
    }
}
