<?php

namespace App\Services\Sms;

use App\Contracts\SmsContract;
use App\Contracts\SmsNotificationContract;
use Illuminate\Support\Facades\Config;
use Kavenegar;

class KavenegarSms extends SmsService implements SmsContract, SmsNotificationContract
{
    public function send()
    {
        $method = $this->method();
        $data   = $this->$method();

        $input_data   = $data['input_data'];
        $mobile       = $this->mobile();
        $template     = $data['template'];

        Config::set('kavenegar.apikey', option('KAVENEGAR_PANEL_APIKEY'));

        try {
            $token   = $input_data['token'] ?? null;
            $token2  = $input_data['token2'] ?? null;
            $token3  = $input_data['token3'] ?? null;
            $token10 = $input_data['token10'] ?? null;
            $token20 = $input_data['token20'] ?? null;

            $result = Kavenegar::VerifyLookup($mobile, $token, $token2, $token3, $template, $type = null, $token10, $token20);

            $response = json_encode($result);
        } catch (\Kavenegar\Exceptions\ApiException $e) {
            // در صورتی که خروجی وب سرویس 200 نباشد این خطا رخ می دهد
            $response = $e->errorMessage();
        } catch (\Kavenegar\Exceptions\HttpException $e) {
            // در زمانی که مشکلی در برقرای ارتباط با وب سرویس وجود داشته باشد این خطا رخ می دهد
            $response = $e->errorMessage();
        }

        return $response;
    }

    public function verifyCode()
    {
        return [
            'template'     => option('sms_forgot_kavenegar'),
            'input_data'   => [
                'token' => $this->data['code']
            ],
        ];
    }

    public function userCreated()
    {
        return [
            'template'     => option('sms_on_user_register_kavenegar'),
            'input_data'   => [
                'token10' => $this->data['nf'],
                'token'   => $this->data['mobile'],
                'token2'   => $this->data['mobile'],
            ],
        ];
    }

    public function factornew()
    {
        return [
            'template'     => option('sms_send_new_factor_kavenegar'),
            'input_data'   => [
                'token10' => $this->data['nf'],
                'token' => $this->data['price'],
                'token20'   => $this->data['name'],
                'token2'=> $this->data['link']

            ],
        ];
    }

    public function userfactorPaid()
    {
        return [
            'template'     => option('sms_ok_factor_user_kavenegar'),
            'input_data'   => [
                'token10' => $this->data['nf'],
                'token' => $this->data['code'],
                'token20'   => $this->data['name'],
                'token2'=> $this->data['price']

            ],
        ];
    }
    public function managerfactorPaid()
    {
        return [
            'template'     => option('sms_ok_factor_manager_kavenegar'),
            'input_data'   => [
                'token10' => $this->data['nf'],
                'token' => $this->data['code'],
                'token2'   => $this->data['price']

            ],
        ];
    }

    public function factorremember()
    {
        return [
            'template'     => option('sms_remember_factor_kavenegar'),
            'input_data'   => [
                'token10' => $this->data['nf'],
                'token' => $this->data['price'],
                'token20'   => $this->data['name'],
                'token2'=> $this->data['link']

            ],
        ];
    }

    public function installment()
    {
        return [
            'template'     => option('sms_installment_kavenegar'),
            'input_data'   => [
                'token10' => $this->data['nf'],
                'token' => $this->data['price'],
                'token20'   => $this->data['name'],
                'token2'=> $this->data['link'],
                'token3'=> $this->data['date']
            ],
        ];
    }
    public function ticketmanager()
    {
        return [
            'template'     => option('sms_ticket_manager_kavenegar'),
            'input_data'   => [
                'token10' => $this->data['nf'],
                'token' => $this->data['id'],
               
            ],
        ];
    }
    public function ticketuser()
    {
        return [
            'template'     => option('sms_ticket_user_kavenegar'),
            'input_data'   => [
                'token10' => $this->data['nf'],
                'token' => $this->data['id'],
            ],
        ];
    }
}
